@@ -74,8 +74,10 @@ test_that("generate_labelled_layer() geenrates a layer for label.", {
 
   expect_equal(generate_labelled_layer(list(l_point), list(g_info), quo(no_such_column), list(fill = "white"), nrow(d)),
                NULL)
-  expect_equal(generate_labelled_layer(list(l_line), list(g_info), type2_quo, list(fill = "white"), 2),
-               ggrepel::geom_label_repel(aes(x, y, colour = type, label = type2), d[c(2, 4), ], fill = "white"))
+  expect_equivalent(
+    generate_labelled_layer(list(l_line), list(g_info), type2_quo, list(fill = "white"), 2),
+    ggrepel::geom_label_repel(aes(x, y, colour = type, label = type2), d[c(2, 4), ], fill = "white")
+  )
   expect_equal(generate_labelled_layer(list(l_bar), list(g_info), type2_quo, list(fill = "white"), nrow(d)),
                list())
   # Do not generate labels when the data is more than max_labels
