@@ -1,3 +1,6 @@
+# FIXME: remove this when https://github.com/r-lib/vdiffr/issues/71 is fixed
+context("vdiffr")
+
 test_that("gghighlight() highlights correctly", {
   vdiffr::expect_doppelganger(
     "simple bar chart",
